.. _combinatorics-group_numbers:

Nilpotent, Abelian and Cyclic Numbers
=====================================

.. module:: sympy.combinatorics.group_numbers

.. autofunction:: is_nilpotent_number

.. autofunction:: is_abelian_number

.. autofunction:: is_cyclic_number
